{% load cms_tags %}
<div class="multicolumn">
{% for plugin in instance.child_plugins_instances %}
	<div style="width: {{ plugin.width }}00px;">
     	{% render_plugin plugin %}
    </div>
{% endfor %}
</div>